@@ -17,7 +17,7 @@
 
 /** @file */
 
-typedef vector<DataProperty*>::iterator DataObjectPropertyIter;
+typedef std::vector<DataProperty*>::iterator DataObjectPropertyIter;
 
 /// A a data set object.
 /** Data objects consist of property-value pairs. */
@@ -25,16 +25,16 @@ class DataObject {
 
   protected:
 
-	vector<DataProperty*> properties;
-	vector<string> s_properties;
-	vector<string> s_nonlocalized_properties;
-	vector<MathStructure*> m_properties;
-	vector<int> a_properties;
+	std::vector<DataProperty*> properties;
+	std::vector<std::string> s_properties;
+	std::vector<std::string> s_nonlocalized_properties;
+	std::vector<MathStructure*> m_properties;
+	std::vector<int> a_properties;
 	DataSet *parent;
 	bool b_uchanged;
-	
+
   public:
- 
+
 	/** Create a data object.
 	*
 	* @param parent_set Data set that the object will belong to.
@@ -52,15 +52,15 @@ class DataObject {
 	* @param s_vale Value for the property.
 	* @param is_approximate If the value is approximate. 1 for approximate, 0 for exact, -1 for property default.
 	*/
-	void setProperty(DataProperty *property, string s_value, int is_approximate = -1);
+	void setProperty(DataProperty *property, std::string s_value, int is_approximate = -1);
 	/** Set an untranslated value for a key property. Used when a text value is translated, but the original value still is needed as a reference key.
 	*
 	* @param property Property to set (must belong to parent data set).
 	* @param s_vale Value for the property.
 	*/
-	void setNonlocalizedKeyProperty(DataProperty *property, string s_value);
-	
-	/** Returns parsed value for a property. Parses the text string value if not parsed before 
+	void setNonlocalizedKeyProperty(DataProperty *property, std::string s_value);
+
+	/** Returns parsed value for a property. Parses the text string value if not parsed before
 	*
 	* @param property Property to read.
 	* @returns Parsed value or NULL if property value is not set.
@@ -72,25 +72,25 @@ class DataObject {
 	* @param[out] is_approximate If the value is approximate. Is set to 1 for approximate, 0 for exact, -1 for property default, if not NULL.
 	* @returns Unparsed value or empty string if property value is not set.
 	*/
-	const string &getProperty(DataProperty *property, int *is_approximate = NULL);
+	const std::string &getProperty(DataProperty *property, int *is_approximate = NULL);
 	/** Returns unparsed untranslated value for a key property. Used when a text value is translated, but the original value still is needed as a reference key.
 	*
 	* @param property Property to read.
 	* @returns Unparsed untranslated value or empty string if property value is not set.
 	*/
-	const string &getNonlocalizedKeyProperty(DataProperty *property);
+	const std::string &getNonlocalizedKeyProperty(DataProperty *property);
 	/** Returns value for a property in a format suitable for use in expressions with unit appended.
 	*
 	* @param property Property to read.
 	* @returns Value in input format or empty string if property value is not set.
 	*/
-	string getPropertyInputString(DataProperty *property);
+	std::string getPropertyInputString(DataProperty *property);
 	/** Returns value for a property in a format suitable for display with unit appended.
 	*
 	* @param property Property to read.
 	* @returns Value in display format or empty string if property value is not set.
 	*/
-	string getPropertyDisplayString(DataProperty *property);
+	std::string getPropertyDisplayString(DataProperty *property);
 
 	/** If the object has been modified by the end user (if setUserModified() has been called).
 	*
@@ -123,15 +123,15 @@ class DataProperty {
 
   protected:
 
-	vector<string> names;
-	vector<bool> name_is_ref;
-	string sdescr, stitle, sunit;
+	std::vector<std::string> names;
+	std::vector<bool> name_is_ref;
+	std::string sdescr, stitle, sunit;
 	MathStructure *m_unit;
 	bool b_approximate, b_brackets, b_key, b_case, b_hide;
 	DataSet *parent;
 	PropertyType ptype;
 	bool b_uchanged;
-	
+
   public:
 
 	/** Create a data property.
@@ -140,29 +140,29 @@ class DataProperty {
 	* @param s_title Descriptive name/title.
 	* @param s_description Description.
 	*/
-	DataProperty(DataSet *parent_set, string s_name = "", string s_title = "", string s_description = "");
+	DataProperty(DataSet *parent_set, std::string s_name = "", std::string s_title = "", std::string s_description = "");
 	DataProperty(const DataProperty &dp);
-	
+
 	void set(const DataProperty &dp);
-	void setName(string s_name, bool is_ref = false);
+	void setName(std::string s_name, bool is_ref = false);
 	void setNameIsReference(size_t index = 1, bool is_ref = true);
 	bool nameIsReference(size_t index = 1) const;
 	void clearNames();
-	void addName(string s_name, bool is_ref = false, size_t index = 0);
-	size_t hasName(const string &s_name);
+	void addName(std::string s_name, bool is_ref = false, size_t index = 0);
+	size_t hasName(const std::string &s_name);
 	size_t countNames() const;
-	const string &getName(size_t index = 1) const;
-	const string &getReferenceName() const;
-	void setTitle(string s_title);
-	const string &title(bool return_name_if_no_title = true) const;
-	void setDescription(string s_description);
-	const string &description() const;
-	void setUnit(string s_unit);
-	const string &getUnitString() const;
+	const std::string &getName(size_t index = 1) const;
+	const std::string &getReferenceName() const;
+	void setTitle(std::string s_title);
+	const std::string &title(bool return_name_if_no_title = true) const;
+	void setDescription(std::string s_description);
+	const std::string &description() const;
+	void setUnit(std::string s_unit);
+	const std::string &getUnitString() const;
 	const MathStructure *getUnitStruct();
-	string getInputString(const string &valuestr);
-	string getDisplayString(const string &valuestr);
-	MathStructure *generateStruct(const string &valuestr, int is_approximate = -1);
+	std::string getInputString(const std::string &valuestr);
+	std::string getDisplayString(const std::string &valuestr);
+	MathStructure *generateStruct(const std::string &valuestr, int is_approximate = -1);
 	void setKey(bool is_key = true);
 	bool isKey() const;
 	void setHidden(bool is_hidden = true);
@@ -175,16 +175,16 @@ class DataProperty {
 	bool isApproximate() const;
 	void setPropertyType(PropertyType property_type);
 	PropertyType propertyType() const;
-	
+
 	bool isUserModified() const;
 	void setUserModified(bool user_modified = true);
-	
+
 	DataSet *parentSet() const;
-	
+
 };
 
-typedef vector<DataProperty*>::iterator DataPropertyIter;
-typedef vector<DataObject*>::iterator DataObjectIter;
+typedef std::vector<DataProperty*>::iterator DataPropertyIter;
+typedef std::vector<DataObject*>::iterator DataObjectIter;
 
 /// A data set.
 /** This is a simple database class for storage of many grouped values, when ordinary variables is not practical.
@@ -197,108 +197,108 @@ typedef vector<DataObject*>::iterator DataObjectIter;
 class DataSet : public MathFunction {
 
   protected:
-  
-	string sfile, scopyright;
+
+	std::string sfile, scopyright;
 	bool b_loaded;
-	vector<DataProperty*> properties;
-	vector<DataObject*> objects;
-	
+	std::vector<DataProperty*> properties;
+	std::vector<DataObject*> objects;
+
   public:
-  
-  	DataSet(string s_category = "", string s_name = "", string s_default_file = "", string s_title = "", string s_description = "", bool is_local = true);
+
+  	DataSet(std::string s_category = "", std::string s_name = "", std::string s_default_file = "", std::string s_title = "", std::string s_description = "", bool is_local = true);
 	DataSet(const DataSet *o);
-	
+
 	ExpressionItem *copy() const;
 	void set(const ExpressionItem *item);
 	int subtype() const;
-	
-	void setCopyright(string s_copyright);
-	const string &copyright() const;
-	void setDefaultDataFile(string s_file);
-	const string &defaultDataFile() const;
-	
-	void setDefaultProperty(string property);
-	const string &defaultProperty() const;
-	
+
+	void setCopyright(std::string s_copyright);
+	const std::string &copyright() const;
+	void setDefaultDataFile(std::string s_file);
+	const std::string &defaultDataFile() const;
+
+	void setDefaultProperty(std::string property);
+	const std::string &defaultProperty() const;
+
 	virtual int calculate(MathStructure &mstruct, const MathStructure &vargs, const EvaluationOptions &eo);
-	
+
 	bool loadObjects(const char *file_name = NULL, bool is_user_defs = true);
 	int saveObjects(const char *file_name = NULL, bool save_global = false);
 	bool objectsLoaded() const;
 	void setObjectsLoaded(bool objects_loaded);
-	
+
 	void addProperty(DataProperty *dp);
 	void delProperty(DataProperty *dp);
 	void delProperty(DataPropertyIter *it);
 	DataProperty *getPrimaryKeyProperty();
-	DataProperty *getProperty(string property);
+	DataProperty *getProperty(std::string property);
 	DataProperty *getFirstProperty(DataPropertyIter *it);
 	DataProperty *getNextProperty(DataPropertyIter *it);
-	const string &getFirstPropertyName(DataPropertyIter *it);
-	const string &getNextPropertyName(DataPropertyIter *it);
-	
+	const std::string &getFirstPropertyName(DataPropertyIter *it);
+	const std::string &getNextPropertyName(DataPropertyIter *it);
+
 	void addObject(DataObject *o);
 	void delObject(DataObject *o);
 	void delObject(DataObjectIter *it);
-	DataObject *getObject(string object);
+	DataObject *getObject(std::string object);
 	DataObject *getObject(const MathStructure &object);
 	DataObject *getFirstObject(DataObjectIter *it);
 	DataObject *getNextObject(DataObjectIter *it);
-	
-	const MathStructure *getObjectProperyStruct(string property, string object);
-	const string &getObjectProperty(string property, string object);
-	string getObjectPropertyInputString(string property, string object);
-	string getObjectPropertyDisplayString(string property, string object);
-	
-	string printProperties(string object);
-	string printProperties(DataObject *o);
-		
+
+	const MathStructure *getObjectProperyStruct(std::string property, std::string object);
+	const std::string &getObjectProperty(std::string property, std::string object);
+	std::string getObjectPropertyInputString(std::string property, std::string object);
+	std::string getObjectPropertyDisplayString(std::string property, std::string object);
+
+	std::string printProperties(std::string object);
+	std::string printProperties(DataObject *o);
+
 };
 
 /// Data property function argument.
 class DataPropertyArgument : public Argument {
 
   protected:
-  
+
   	DataSet *o_data;
-  
-	virtual bool subtest(MathStructure &value, const EvaluationOptions &eo) const;  
-	virtual string subprintlong() const;
+
+	virtual bool subtest(MathStructure &value, const EvaluationOptions &eo) const;
+	virtual std::string subprintlong() const;
 
   public:
-  
-  	DataPropertyArgument(DataSet *data_set, string name_ = "", bool does_test = true, bool does_error = true);
+
+  	DataPropertyArgument(DataSet *data_set, std::string name_ = "", bool does_test = true, bool does_error = true);
 	DataPropertyArgument(const DataPropertyArgument *arg);
 	~DataPropertyArgument();
 	int type() const;
 	Argument *copy() const;
-	string print() const;
+	std::string print() const;
 	DataSet *dataSet() const;
 	void setDataSet(DataSet *data_set);
-	
+
 };
 
 /// Data object function argument.
 class DataObjectArgument : public Argument {
 
   protected:
-  
+
   	DataSet *o_data;
-  
-	virtual bool subtest(MathStructure &value, const EvaluationOptions &eo) const;  
-	virtual string subprintlong() const;
+
+	virtual bool subtest(MathStructure &value, const EvaluationOptions &eo) const;
+	virtual std::string subprintlong() const;
 
   public:
-  
-  	DataObjectArgument(DataSet *data_set, string name_ = "", bool does_test = true, bool does_error = true);
+
+  	DataObjectArgument(DataSet *data_set, std::string name_ = "", bool does_test = true, bool does_error = true);
 	DataObjectArgument(const DataObjectArgument *arg);
 	~DataObjectArgument();
 	int type() const;
 	Argument *copy() const;
-	string print() const;
+	std::string print() const;
 	DataSet *dataSet() const;
 	void setDataSet(DataSet *data_set);
-	
+
 };
 
 #endif
