@@ -180,7 +180,7 @@ QalculateDateTime nextLeapSecond(const QalculateDateTime &date) {
 }
 QalculateDateTime prevLeapSecond(const QalculateDateTime &date) {
 	if(date.year() < LS_FIRST_YEAR) return QalculateDateTime();
-	size_t halfyear = sizeof(has_leap_second);
+	size_t halfyear = sizeof(has_leap_second) - 1;
 	if(date.year() <= LS_LAST_YEAR) {
 		halfyear = (date.year() - LS_FIRST_YEAR) * 2;
 		if(date.month() <= 6) {
@@ -202,6 +202,11 @@ QalculateDateTime prevLeapSecond(const QalculateDateTime &date) {
 
 int dateTimeZone(time_t rawtime) {
 	struct tm tmdate = *localtime(&rawtime);
+#ifdef _WIN32
+	TIME_ZONE_INFORMATION TimeZoneInfo;
+	GetTimeZoneInformation(&TimeZoneInfo);
+	return -(TimeZoneInfo.Bias + (tmdate.tm_isdst ? TimeZoneInfo.DaylightBias : TimeZoneInfo.StandardBias));
+#else
 	char buffer[10];
 	if(!strftime(buffer, 10, "%z", &tmdate)) {
 		return 0;
@@ -210,6 +215,7 @@ int dateTimeZone(time_t rawtime) {
 	int h = s2i(s.substr(0, 3));
 	int m = s2i(s.substr(3));
 	return h * 60 + m;
+#endif
 }
 int dateTimeZone(const QalculateDateTime &dt, bool b_utc) {
 	struct tm tmdate;
