@@ -49,6 +49,8 @@
 #endif
 
 using std::string;
+using std::endl;
+using std::cout;
 using std::vector;
 using std::ifstream;
 using std::ofstream;
@@ -194,9 +196,21 @@ const char *b2oo(bool b, bool capital) {
 	return _("off");
 }
 long int s2i(const string& str) {
+	if(str.find(' ') != string::npos) {
+		string str2 = str;
+		remove_blanks(str2);
+		return strtol(str2.c_str(), NULL, 10);
+	}
 	return strtol(str.c_str(), NULL, 10);
 }
 long int s2i(const char *str) {
+	for(size_t i = 0; i < strlen(str); i++) {
+		if(str[i] == ' ') {
+			string str2 = str;
+			remove_blanks(str2);
+			return strtol(str2.c_str(), NULL, 10);
+		}
+	}
 	return strtol(str, NULL, 10);
 }
 void *s2p(const string& str) {
@@ -312,6 +326,15 @@ size_t unicode_length(const string &str) {
 	}
 	return l2;
 }
+size_t unicode_length(const string &str, size_t l) {
+	size_t l2 = 0;
+	for(size_t i = 0; i < l; i++) {
+		if((signed char) str[i] > 0 || (unsigned char) str[i] >= 0xC0) {
+			l2++;
+		}
+	}
+	return l2;
+}
 size_t unicode_length(const char *str) {
 	size_t l = strlen(str), l2 = 0;
 	for(size_t i = 0; i < l; i++) {
@@ -321,7 +344,15 @@ size_t unicode_length(const char *str) {
 	}
 	return l2;
 }
-
+size_t unicode_length(const char *str, size_t l) {
+	size_t l2 = 0;
+	for(size_t i = 0; i < l; i++) {
+		if((signed char) str[i] > 0 || (unsigned char) str[i] >= 0xC0) {
+			l2++;
+		}
+	}
+	return l2;
+}
 bool text_length_is_one(const string &str) {
 	if(str.empty()) return false;
 	if(str.length() == 1) return true;
@@ -380,7 +411,6 @@ bool equalsIgnoreCase(const string &str1, const string &str2) {
 	}
 	return true;
 }
-
 bool equalsIgnoreCase(const string &str1, const char *str2) {
 	if(str1.empty() || strlen(str2) == 0) return false;
 	for(size_t i1 = 0, i2 = 0; i1 < str1.length() || i2 < strlen(str2); i1++, i2++) {
@@ -447,11 +477,10 @@ string sub_suffix_html(const string &name) {
 	} else {
 		str += name.substr(0, i);
 	}
+	str += "<sub>";
 	if(b) {
-		str += "<sub class=\"nous\">";
 		str += name.substr(name.length() - i2, i2);
 	} else {
-		str += "<sub>";
 		str += name.substr(i + 1, name.length() - (i + 1));
 	}
 	str += "</sub>";
@@ -866,6 +895,36 @@ char *utf8_strdown(const char *str, int l) {
 #endif
 }
 
+char *utf8_strup(const char *str, int l) {
+#ifdef HAVE_ICU
+	if(!ucm) return NULL;
+	UErrorCode err = U_ZERO_ERROR;
+	size_t inlength = l <= 0 ? strlen(str) : (size_t) l;
+	size_t outlength = inlength + 4;
+	char *buffer = (char*) malloc(outlength * sizeof(char));
+	if(!buffer) return NULL;
+	int32_t length = ucasemap_utf8ToUpper(ucm, buffer, outlength, str, inlength, &err);
+	if(U_SUCCESS(err)) {
+		return buffer;
+	} else if(err == U_BUFFER_OVERFLOW_ERROR) {
+		outlength = length + 4;
+		char *buffer_realloc = (char*) realloc(buffer, outlength * sizeof(char));
+		if(buffer_realloc) buffer = buffer_realloc;
+		else {free(buffer); return NULL;}
+		err = U_ZERO_ERROR;
+		ucasemap_utf8ToUpper(ucm, buffer, outlength, str, inlength, &err);
+		if(U_SUCCESS(err)) {
+			return buffer;
+		} else {
+			free(buffer);
+		}
+	}
+	return NULL;
+#else
+	return NULL;
+#endif
+}
+
 extern size_t write_data(void *ptr, size_t size, size_t nmemb, string *sbuffer);
 int checkAvailableVersion(const char *version_id, const char *current_version, string *available_version, int timeout) {
 #ifdef HAVE_LIBCURL
